@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1402';
+our $VERSION = '0.1500';
 
 use strict;
 use warnings;
@@ -220,8 +220,12 @@ sub email_modifier {
         # Break up the name.
         my @name = split / /, $p;
 
-        # Turn any unicode characters into something ascii.
-        $_ = unidecode($_) for @name;
+        for ( @name ) {
+            # Turn any unicode characters into something ascii.
+            $_ = unidecode($_);
+            # Remove non-alpha_nums
+            s/\W//g;
+        }
 
         # Add an email address for the person.
         my $email = lc($name[0]);
@@ -393,7 +397,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1402
+version 0.1500
 
 =head1 SYNOPSIS
 
